@@ -7,7 +7,7 @@ use namespace::autoclean;
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-our $VERSION = "0.700";
+our $VERSION = "0.701";
 $VERSION = eval $VERSION;
 
 use Dist::Zilla::PluginBundle::Filter;
@@ -33,7 +33,7 @@ Dist::Zilla::PluginBundle::IDOPEREL - IDOPEREL's plugin bundle for Dist::Zilla.
 
 =head1 VERSION
 
-version 0.700
+version 0.701
 
 =head1 SYNOPSIS
 
@@ -88,7 +88,7 @@ sub configure {
 	$self->add_plugins(
 		'VersionFromModule',
 
-		[ 'AutoPrereqs' => { skip => $self->payload->{auto_prereqs_skip} } ],
+		[ 'AutoPrereqs' => { skip => $self->payload->{auto_prereqs_skip} || [] } ],
 
 		'CheckChangesHasContent',
 		'DistManifestTests',
@@ -154,4 +154,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-1;
\ No newline at end of file
+1;
